@@ -40,28 +40,25 @@
 
 namespace aria2 {
 
-Pref::Pref(const char* k, size_t i):k(k), i(i) {}
+Pref::Pref(const char* k, size_t i) : k(k), i(i) {}
 
 namespace {
 
 class PrefFactory {
 public:
-  PrefFactory():count_(0)
+  PrefFactory() : count_(0)
   {
     // We add special null pref whose ID is 0.
     makePref("");
   }
   ~PrefFactory()
   {
-    for(size_t i = 0; i < count_; ++i) {
+    for (size_t i = 0; i < count_; ++i) {
       delete i2p_[i];
     }
   }
 
-  size_t nextId()
-  {
-    return count_++;
-  }
+  size_t nextId() { return count_++; }
   Pref* makePref(const char* key)
   {
     size_t id = nextId();
@@ -70,10 +67,7 @@ public:
     k2p_[key] = pref;
     return pref;
   }
-  size_t getCount() const
-  {
-    return count_;
-  }
+  size_t getCount() const { return count_; }
   PrefPtr i2p(size_t id) const
   {
     assert(id < count_);
@@ -82,7 +76,7 @@ public:
   PrefPtr k2p(const std::string& k) const
   {
     auto i = k2p_.find(k);
-    if(i == k2p_.end()) {
+    if (i == k2p_.end()) {
       return i2p_[0];
     }
     return (*i).second;
@@ -101,34 +95,19 @@ PrefFactory* getPrefFactory()
   return pf;
 }
 
-Pref* makePref(const char* key)
-{
-  return getPrefFactory()->makePref(key);
-}
+Pref* makePref(const char* key) { return getPrefFactory()->makePref(key); }
 
 } // namespace
 
 namespace option {
 
-size_t countOption()
-{
-  return getPrefFactory()->getCount();
-}
+size_t countOption() { return getPrefFactory()->getCount(); }
 
-PrefPtr i2p(size_t id)
-{
-  return getPrefFactory()->i2p(id);
-}
+PrefPtr i2p(size_t id) { return getPrefFactory()->i2p(id); }
 
-PrefPtr k2p(const std::string& key)
-{
-  return getPrefFactory()->k2p(key);
-}
+PrefPtr k2p(const std::string& key) { return getPrefFactory()->k2p(key); }
 
-void deletePrefResource()
-{
-  delete getPrefFactory();
-}
+void deletePrefResource() { delete getPrefFactory(); }
 
 } // namespace option
 
@@ -142,6 +121,7 @@ const std::string V_NONE("none");
 const std::string V_MEM("mem");
 const std::string V_ALL("all");
 const std::string A2_V_FULL("full");
+const std::string A2_V_HIDE("hide");
 const std::string A2_V_GEOM("geom");
 const std::string V_PREALLOC("prealloc");
 const std::string V_FALLOC("falloc");
@@ -152,6 +132,7 @@ const std::string V_NOTICE("notice");
 const std::string V_WARN("warn");
 const std::string V_ERROR("error");
 const std::string V_INORDER("inorder");
+const std::string A2_V_RANDOM("random");
 const std::string V_FEEDBACK("feedback");
 const std::string V_ADAPTIVE("adaptive");
 const std::string V_LIBUV("libuv");
@@ -207,7 +188,8 @@ PrefPtr PREF_LOWEST_SPEED_LIMIT = makePref("lowest-speed-limit");
 // value: 1*digit
 PrefPtr PREF_PIECE_LENGTH = makePref("piece-length");
 // value: 1*digit
-PrefPtr PREF_MAX_OVERALL_DOWNLOAD_LIMIT = makePref("max-overall-download-limit");
+PrefPtr PREF_MAX_OVERALL_DOWNLOAD_LIMIT =
+    makePref("max-overall-download-limit");
 // value: 1*digit
 PrefPtr PREF_MAX_DOWNLOAD_LIMIT = makePref("max-download-limit");
 // value: 1*digit
@@ -236,6 +218,15 @@ PrefPtr PREF_INPUT_FILE = makePref("input-file");
 PrefPtr PREF_DEFERRED_INPUT = makePref("deferred-input");
 // value: 1*digit
 PrefPtr PREF_MAX_CONCURRENT_DOWNLOADS = makePref("max-concurrent-downloads");
+// value: true | false | A:B
+PrefPtr PREF_OPTIMIZE_CONCURRENT_DOWNLOADS =
+    makePref("optimize-concurrent-downloads");
+// values: 1*digit ['.' [ 1*digit ] ]
+PrefPtr PREF_OPTIMIZE_CONCURRENT_DOWNLOADS_COEFFA =
+    makePref("optimize-concurrent-downloads-coeffA");
+// values: 1*digit ['.' [ 1*digit ] ]
+PrefPtr PREF_OPTIMIZE_CONCURRENT_DOWNLOADS_COEFFB =
+    makePref("optimize-concurrent-downloads-coeffB");
 // value: true | false
 PrefPtr PREF_FORCE_SEQUENTIAL = makePref("force-sequential");
 // value: true | false
@@ -308,6 +299,8 @@ PrefPtr PREF_ON_DOWNLOAD_COMPLETE = makePref("on-download-complete");
 PrefPtr PREF_ON_DOWNLOAD_ERROR = makePref("on-download-error");
 // value: string
 PrefPtr PREF_INTERFACE = makePref("interface");
+// value: string
+PrefPtr PREF_MULTIPLE_INTERFACE = makePref("multiple-interface");
 // value: true | false
 PrefPtr PREF_DISABLE_IPV6 = makePref("disable-ipv6");
 // value: true | false
@@ -344,7 +337,7 @@ PrefPtr PREF_STREAM_PIECE_SELECTOR = makePref("stream-piece-selector");
 PrefPtr PREF_TRUNCATE_CONSOLE_READOUT = makePref("truncate-console-readout");
 // value: true | false
 PrefPtr PREF_PAUSE = makePref("pause");
-// value: default | full
+// value: default | full | hide
 PrefPtr PREF_DOWNLOAD_RESULT = makePref("download-result");
 // value: true | false
 PrefPtr PREF_HASH_CHECK_ONLY = makePref("hash-check-only");
@@ -356,6 +349,8 @@ PrefPtr PREF_STOP_WITH_PROCESS = makePref("stop-with-process");
 PrefPtr PREF_ENABLE_MMAP = makePref("enable-mmap");
 // value: true | false
 PrefPtr PREF_FORCE_SAVE = makePref("force-save");
+// value: true | false
+PrefPtr PREF_SAVE_NOT_FOUND = makePref("save-not-found");
 // value: 1*digit
 PrefPtr PREF_DISK_CACHE = makePref("disk-cache");
 // value: string
@@ -373,6 +368,15 @@ PrefPtr PREF_PAUSE_METADATA = makePref("pause-metadata");
 PrefPtr PREF_RLIMIT_NOFILE = makePref("rlimit-nofile");
 // values: SSLv3 | TLSv1 | TLSv1.1 | TLSv1.2
 PrefPtr PREF_MIN_TLS_VERSION = makePref("min-tls-version");
+// value: 1*digit
+PrefPtr PREF_SOCKET_RECV_BUFFER_SIZE = makePref("socket-recv-buffer-size");
+// value: 1*digit
+PrefPtr PREF_MAX_MMAP_LIMIT = makePref("max-mmap-limit");
+// value: true | false
+PrefPtr PREF_STDERR = makePref("stderr");
+// value: true | false
+PrefPtr PREF_KEEP_UNFINISHED_DOWNLOAD_RESULT =
+    makePref("keep-unfinished-download-result");
 
 /**
  * FTP related preferences
@@ -385,6 +389,8 @@ PrefPtr PREF_FTP_TYPE = makePref("ftp-type");
 PrefPtr PREF_FTP_PASV = makePref("ftp-pasv");
 // values: true | false
 PrefPtr PREF_FTP_REUSE_CONNECTION = makePref("ftp-reuse-connection");
+// values: hashType=digest
+PrefPtr PREF_SSH_HOST_KEY_MD = makePref("ssh-host-key-md");
 
 /**
  * HTTP related preferences
@@ -421,6 +427,9 @@ PrefPtr PREF_HTTP_AUTH_CHALLENGE = makePref("http-auth-challenge");
 PrefPtr PREF_HTTP_NO_CACHE = makePref("http-no-cache");
 // value: true | false
 PrefPtr PREF_HTTP_ACCEPT_GZIP = makePref("http-accept-gzip");
+// value: true | false
+PrefPtr PREF_CONTENT_DISPOSITION_DEFAULT_UTF8 =
+    makePref("content-disposition-default-utf8");
 
 /**
  * Proxy related preferences
@@ -506,7 +515,8 @@ PrefPtr PREF_BT_MIN_CRYPTO_LEVEL = makePref("bt-min-crypto-level");
 // values:: true | false
 PrefPtr PREF_BT_REQUIRE_CRYPTO = makePref("bt-require-crypto");
 // values: 1*digit
-PrefPtr PREF_BT_REQUEST_PEER_SPEED_LIMIT = makePref("bt-request-peer-speed-limit");
+PrefPtr PREF_BT_REQUEST_PEER_SPEED_LIMIT =
+    makePref("bt-request-peer-speed-limit");
 // values: 1*digit
 PrefPtr PREF_BT_MAX_OPEN_FILES = makePref("bt-max-open-files");
 // values: true | false
@@ -536,7 +546,8 @@ PrefPtr PREF_BT_LPD_INTERFACE = makePref("bt-lpd-interface");
 // values: 1*digit
 PrefPtr PREF_BT_TRACKER_TIMEOUT = makePref("bt-tracker-timeout");
 // values: 1*digit
-PrefPtr PREF_BT_TRACKER_CONNECT_TIMEOUT = makePref("bt-tracker-connect-timeout");
+PrefPtr PREF_BT_TRACKER_CONNECT_TIMEOUT =
+    makePref("bt-tracker-connect-timeout");
 // values: 1*digit
 PrefPtr PREF_DHT_MESSAGE_TIMEOUT = makePref("dht-message-timeout");
 // values: string
@@ -546,10 +557,12 @@ PrefPtr PREF_BT_TRACKER = makePref("bt-tracker");
 // values: string
 PrefPtr PREF_BT_EXCLUDE_TRACKER = makePref("bt-exclude-tracker");
 // values: true | false
-PrefPtr PREF_BT_REMOVE_UNSELECTED_FILE =
-  makePref("bt-remove-unselected-file");
+PrefPtr PREF_BT_REMOVE_UNSELECTED_FILE = makePref("bt-remove-unselected-file");
 PrefPtr PREF_BT_DETACH_SEED_ONLY = makePref("bt-detach-seed-only");
 PrefPtr PREF_BT_FORCE_ENCRYPTION = makePref("bt-force-encryption");
+// values: true | false
+PrefPtr PREF_BT_ENABLE_HOOK_AFTER_HASH_CHECK =
+    makePref("bt-enable-hook-after-hash-check");
 
 /**
  * Metalink related preferences
@@ -567,9 +580,11 @@ PrefPtr PREF_METALINK_LOCATION = makePref("metalink-location");
 // values: true | false | mem
 PrefPtr PREF_FOLLOW_METALINK = makePref("follow-metalink");
 // values: http | https | ftp | none
-PrefPtr PREF_METALINK_PREFERRED_PROTOCOL = makePref("metalink-preferred-protocol");
+PrefPtr PREF_METALINK_PREFERRED_PROTOCOL =
+    makePref("metalink-preferred-protocol");
 // values: true | false
-PrefPtr PREF_METALINK_ENABLE_UNIQUE_PROTOCOL = makePref("metalink-enable-unique-protocol");
+PrefPtr PREF_METALINK_ENABLE_UNIQUE_PROTOCOL =
+    makePref("metalink-enable-unique-protocol");
 PrefPtr PREF_METALINK_BASE_URI = makePref("metalink-base-uri");
 
 } // namespace aria2
